@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-07-30'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2015-08-19'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -168,6 +168,28 @@ sub munge_files {
         name => "bin/$scriptname", content => $res->[2]);
     $self->log(["Creating script 'bin/%s' from Riap function '%s'", $scriptname, $self->url]);
     $self->add_file($fileobj);
+
+    # create a separate completion script if we use Perinci::CmdLine::Inline,
+    # because Perinci::CmdLine::Inline currently does not support completion
+    # natively.
+    if ($res->[3]{'func.cmdline_module_inlined'}) {
+        require App::GenPericmdCompleterScript;
+        my $compres = App::GenPericmdCompleterScript::gen_perinci_cmdline_completer_script(
+            url => $self->url,
+            subcommands => $subcommands,
+            skip_format => $self->skip_format,
+            program_name => $scriptname,
+            load_module => $self->load_modules,
+            read_config => 0,
+            read_env => 0,
+        );
+        $self->log_fatal("Failed generating completer script _$scriptname: $compres->[0] - $compres->[1]")
+            unless $compres->[0] == 200;
+        my $compfileobj = Dist::Zilla::File::InMemory->new(
+            name => "bin/_$scriptname", content => $compres->[2]);
+        $self->log(["Creating completer script 'bin/_%s' from Riap function '%s'", $scriptname, $self->url]);
+        $self->add_file($compfileobj);
+    }
 }
 
 
@@ -187,7 +209,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.22 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-30.
+This document describes version 0.23 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-08-19.
 
 =head1 SYNOPSIS
 
@@ -356,7 +378,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
 
 =head1 BUGS
 
